pub enum DownloadedAccount {
Unknown,
Absent,
Present(Account),
}Expand description
What the downloaded state holds for an account a list changes.
Variants
Unknown
The account’s range is not downloaded yet.
Absent
The account’s range is downloaded and does not hold it.
Present(Account)
The downloaded account.